@@ -103,7 +103,8 @@ void FBLoginDialog::dialogDidSucceed(const QUrl& aUrl)
         }
         else
         {
-            token = url.right(delta);
+            // -1 because delta assumes & character which is in this case missing
+            token = url.right(delta - 1);
         }
 
         connectToGetSession(token);
